==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/kubernetesenv/KubernetesenvListFluent.java <==
package me.snowdrop.istio.mixer.adapter.kubernetesenv;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface KubernetesenvListFluent<A extends KubernetesenvListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,Kubernetesenv item);
    public A setToItems(int index,Kubernetesenv item);
    public A addToItems(Kubernetesenv... items);
    public A addAllToItems(Collection<Kubernetesenv> items);
    public A removeFromItems(Kubernetesenv... items);
    public A removeAllFromItems(Collection<Kubernetesenv> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Kubernetesenv> getItems();
    public List<Kubernetesenv> buildItems();
    public Kubernetesenv buildItem(int index);
    public Kubernetesenv buildFirstItem();
    public Kubernetesenv buildLastItem();
    public Kubernetesenv buildMatchingItem(Predicate<KubernetesenvBuilder> predicate);
    public A withItems(List<Kubernetesenv> items);
    public A withItems(Kubernetesenv... items);
    public Boolean hasItems();
    public KubernetesenvListFluent.ItemsNested<A> addNewItem();
    public KubernetesenvListFluent.ItemsNested<A> addNewItemLike(Kubernetesenv item);
    public KubernetesenvListFluent.ItemsNested<A> setNewItemLike(int index,Kubernetesenv item);
    public KubernetesenvListFluent.ItemsNested<A> editItem(int index);
    public KubernetesenvListFluent.ItemsNested<A> editFirstItem();
    public KubernetesenvListFluent.ItemsNested<A> editLastItem();
    public KubernetesenvListFluent.ItemsNested<A> editMatchingItem(Predicate<KubernetesenvBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,KubernetesenvFluent<KubernetesenvListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/kubernetesenv/KubernetesenvListFluent.java <==
package me.snowdrop.istio.mixer.adapter.kubernetesenv;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface KubernetesenvListFluent<A extends KubernetesenvListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Kubernetesenv item);
    public A setToItems(int index,Kubernetesenv item);
    public A addToItems(Kubernetesenv... items);
    public A addAllToItems(Collection<Kubernetesenv> items);
    public A removeFromItems(Kubernetesenv... items);
    public A removeAllFromItems(Collection<Kubernetesenv> items);
    public A removeMatchingFromItems(Predicate<KubernetesenvBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Kubernetesenv> getItems();
    public List<Kubernetesenv> buildItems();
    public Kubernetesenv buildItem(int index);
    public Kubernetesenv buildFirstItem();
    public Kubernetesenv buildLastItem();
    public Kubernetesenv buildMatchingItem(Predicate<KubernetesenvBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<KubernetesenvBuilder> predicate);
    public A withItems(List<Kubernetesenv> items);
    public A withItems(Kubernetesenv... items);
    public Boolean hasItems();
    public KubernetesenvListFluent.ItemsNested<A> addNewItem();
    public KubernetesenvListFluent.ItemsNested<A> addNewItemLike(Kubernetesenv item);
    public KubernetesenvListFluent.ItemsNested<A> setNewItemLike(int index,Kubernetesenv item);
    public KubernetesenvListFluent.ItemsNested<A> editItem(int index);
    public KubernetesenvListFluent.ItemsNested<A> editFirstItem();
    public KubernetesenvListFluent.ItemsNested<A> editLastItem();
    public KubernetesenvListFluent.ItemsNested<A> editMatchingItem(Predicate<KubernetesenvBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,KubernetesenvFluent<KubernetesenvListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
